# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DeliverabilityTestControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_deliverability_simulation_job(self, test_id, job_id, **kwargs):  # noqa: E501
        """Cancel deliverability simulation job  # noqa: E501

        Cancel a running or paused simulation job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_deliverability_simulation_job(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilitySimulationJobDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.cancel_deliverability_simulation_job_with_http_info(test_id, job_id, **kwargs)  # noqa: E501

    def cancel_deliverability_simulation_job_with_http_info(self, test_id, job_id, **kwargs):  # noqa: E501
        """Cancel deliverability simulation job  # noqa: E501

        Cancel a running or paused simulation job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_deliverability_simulation_job_with_http_info(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilitySimulationJobDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'job_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_deliverability_simulation_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `cancel_deliverability_simulation_job`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_id` when calling `cancel_deliverability_simulation_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501
        if 'job_id' in local_var_params:
            path_params['jobId'] = local_var_params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/simulation-jobs/{jobId}/cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilitySimulationJobDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_deliverability_simulation_job(self, test_id, create_deliverability_simulation_job_options, **kwargs):  # noqa: E501
        """Create deliverability simulation job  # noqa: E501

        Create and start a simulation job for a running deliverability test. Only one active simulation job is allowed per user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_deliverability_simulation_job(test_id, create_deliverability_simulation_job_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param CreateDeliverabilitySimulationJobOptions create_deliverability_simulation_job_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilitySimulationJobDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_deliverability_simulation_job_with_http_info(test_id, create_deliverability_simulation_job_options, **kwargs)  # noqa: E501

    def create_deliverability_simulation_job_with_http_info(self, test_id, create_deliverability_simulation_job_options, **kwargs):  # noqa: E501
        """Create deliverability simulation job  # noqa: E501

        Create and start a simulation job for a running deliverability test. Only one active simulation job is allowed per user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_deliverability_simulation_job_with_http_info(test_id, create_deliverability_simulation_job_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param CreateDeliverabilitySimulationJobOptions create_deliverability_simulation_job_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilitySimulationJobDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'create_deliverability_simulation_job_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_deliverability_simulation_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `create_deliverability_simulation_job`")  # noqa: E501
        # verify the required parameter 'create_deliverability_simulation_job_options' is set
        if self.api_client.client_side_validation and ('create_deliverability_simulation_job_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_deliverability_simulation_job_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_deliverability_simulation_job_options` when calling `create_deliverability_simulation_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_deliverability_simulation_job_options' in local_var_params:
            body_params = local_var_params['create_deliverability_simulation_job_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/simulation-jobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilitySimulationJobDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_deliverability_test(self, create_deliverability_test_options, **kwargs):  # noqa: E501
        """Create deliverability/load test  # noqa: E501

        Create a deliverability test for inboxes or phone numbers using ALL, PATTERN, or EXPLICIT selector scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_deliverability_test(create_deliverability_test_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateDeliverabilityTestOptions create_deliverability_test_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_deliverability_test_with_http_info(create_deliverability_test_options, **kwargs)  # noqa: E501

    def create_deliverability_test_with_http_info(self, create_deliverability_test_options, **kwargs):  # noqa: E501
        """Create deliverability/load test  # noqa: E501

        Create a deliverability test for inboxes or phone numbers using ALL, PATTERN, or EXPLICIT selector scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_deliverability_test_with_http_info(create_deliverability_test_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateDeliverabilityTestOptions create_deliverability_test_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_deliverability_test_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_deliverability_test_options' is set
        if self.api_client.client_side_validation and ('create_deliverability_test_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_deliverability_test_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_deliverability_test_options` when calling `create_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_deliverability_test_options' in local_var_params:
            body_params = local_var_params['create_deliverability_test_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_deliverability_test(self, test_id, **kwargs):  # noqa: E501
        """Delete deliverability/load test  # noqa: E501

        Delete test and all persisted entity-level results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_deliverability_test(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeleteResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_deliverability_test_with_http_info(test_id, **kwargs)  # noqa: E501

    def delete_deliverability_test_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Delete deliverability/load test  # noqa: E501

        Delete test and all persisted entity-level results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_deliverability_test_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeleteResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `delete_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def duplicate_deliverability_test(self, test_id, **kwargs):  # noqa: E501
        """Duplicate deliverability/load test  # noqa: E501

        Create a fresh deliverability test using an existing test configuration, including selector scope, exclusions, and expectations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.duplicate_deliverability_test(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.duplicate_deliverability_test_with_http_info(test_id, **kwargs)  # noqa: E501

    def duplicate_deliverability_test_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Duplicate deliverability/load test  # noqa: E501

        Create a fresh deliverability test using an existing test configuration, including selector scope, exclusions, and expectations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.duplicate_deliverability_test_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method duplicate_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `duplicate_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/duplicate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_deliverability_test_report(self, test_id, **kwargs):  # noqa: E501
        """Export deliverability/load test report as PDF  # noqa: E501

        Export a PDF report for a terminal deliverability test (COMPLETE, FAILED, or STOPPED), including configuration, summary outcomes, and detailed entity-level results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_deliverability_test_report(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_deliverability_test_report_with_http_info(test_id, **kwargs)  # noqa: E501

    def export_deliverability_test_report_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Export deliverability/load test report as PDF  # noqa: E501

        Export a PDF report for a terminal deliverability test (COMPLETE, FAILED, or STOPPED), including configuration, summary outcomes, and detailed entity-level results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_deliverability_test_report_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_deliverability_test_report" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `export_deliverability_test_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/report/export', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_deliverability_test_results(self, test_id, **kwargs):  # noqa: E501
        """Export deliverability/load test entity results as CSV  # noqa: E501

        Export per-entity deliverability results including expectation-level pass/fail counts. The latest status is evaluated with the same polling safeguards before export.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_deliverability_test_results(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param bool matched:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_deliverability_test_results_with_http_info(test_id, **kwargs)  # noqa: E501

    def export_deliverability_test_results_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Export deliverability/load test entity results as CSV  # noqa: E501

        Export per-entity deliverability results including expectation-level pass/fail counts. The latest status is evaluated with the same polling safeguards before export.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_deliverability_test_results_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param bool matched:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'matched'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_deliverability_test_results" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `export_deliverability_test_results`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []
        if 'matched' in local_var_params and local_var_params['matched'] is not None:  # noqa: E501
            query_params.append(('matched', local_var_params['matched']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/results/export', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_deliverability_analytics_series(self, **kwargs):  # noqa: E501
        """Get deliverability analytics time series  # noqa: E501

        Compare deliverability runs over a time range with bucketed chart metrics and run-level rows for table views.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_analytics_series(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param datetime since:
        :param datetime before:
        :param str scope:
        :param str bucket:
        :param int run_limit:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityAnalyticsSeriesDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_deliverability_analytics_series_with_http_info(**kwargs)  # noqa: E501

    def get_deliverability_analytics_series_with_http_info(self, **kwargs):  # noqa: E501
        """Get deliverability analytics time series  # noqa: E501

        Compare deliverability runs over a time range with bucketed chart metrics and run-level rows for table views.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_analytics_series_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param datetime since:
        :param datetime before:
        :param str scope:
        :param str bucket:
        :param int run_limit:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityAnalyticsSeriesDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'since',
            'before',
            'scope',
            'bucket',
            'run_limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_deliverability_analytics_series" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'scope' in local_var_params and local_var_params['scope'] is not None:  # noqa: E501
            query_params.append(('scope', local_var_params['scope']))  # noqa: E501
        if 'bucket' in local_var_params and local_var_params['bucket'] is not None:  # noqa: E501
            query_params.append(('bucket', local_var_params['bucket']))  # noqa: E501
        if 'run_limit' in local_var_params and local_var_params['run_limit'] is not None:  # noqa: E501
            query_params.append(('runLimit', local_var_params['run_limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/analytics/series', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityAnalyticsSeriesDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_deliverability_failure_hotspots(self, **kwargs):  # noqa: E501
        """Get deliverability failure hotspots  # noqa: E501

        Find commonly failing entities and phone country/variant dimensions across deliverability runs in a time range.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_failure_hotspots(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param datetime since:
        :param datetime before:
        :param str scope:
        :param int limit:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityFailureHotspotsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_deliverability_failure_hotspots_with_http_info(**kwargs)  # noqa: E501

    def get_deliverability_failure_hotspots_with_http_info(self, **kwargs):  # noqa: E501
        """Get deliverability failure hotspots  # noqa: E501

        Find commonly failing entities and phone country/variant dimensions across deliverability runs in a time range.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_failure_hotspots_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param datetime since:
        :param datetime before:
        :param str scope:
        :param int limit:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityFailureHotspotsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'since',
            'before',
            'scope',
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_deliverability_failure_hotspots" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'scope' in local_var_params and local_var_params['scope'] is not None:  # noqa: E501
            query_params.append(('scope', local_var_params['scope']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/analytics/hotspots', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityFailureHotspotsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_deliverability_simulation_job(self, test_id, job_id, **kwargs):  # noqa: E501
        """Get deliverability simulation job  # noqa: E501

        Get simulation job status and progress counters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_simulation_job(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilitySimulationJobDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_deliverability_simulation_job_with_http_info(test_id, job_id, **kwargs)  # noqa: E501

    def get_deliverability_simulation_job_with_http_info(self, test_id, job_id, **kwargs):  # noqa: E501
        """Get deliverability simulation job  # noqa: E501

        Get simulation job status and progress counters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_simulation_job_with_http_info(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilitySimulationJobDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'job_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_deliverability_simulation_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `get_deliverability_simulation_job`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_id` when calling `get_deliverability_simulation_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501
        if 'job_id' in local_var_params:
            path_params['jobId'] = local_var_params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/simulation-jobs/{jobId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilitySimulationJobDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_deliverability_simulation_job_events(self, test_id, job_id, **kwargs):  # noqa: E501
        """Get deliverability simulation job events  # noqa: E501

        Get paged simulation events including send successes and failures.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_simulation_job_events(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param int page:
        :param int size:
        :param str sort:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilitySimulationJobEventPageDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_deliverability_simulation_job_events_with_http_info(test_id, job_id, **kwargs)  # noqa: E501

    def get_deliverability_simulation_job_events_with_http_info(self, test_id, job_id, **kwargs):  # noqa: E501
        """Get deliverability simulation job events  # noqa: E501

        Get paged simulation events including send successes and failures.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_simulation_job_events_with_http_info(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param int page:
        :param int size:
        :param str sort:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilitySimulationJobEventPageDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'job_id',
            'page',
            'size',
            'sort'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_deliverability_simulation_job_events" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `get_deliverability_simulation_job_events`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_id` when calling `get_deliverability_simulation_job_events`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501
        if 'job_id' in local_var_params:
            path_params['jobId'] = local_var_params['job_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/simulation-jobs/{jobId}/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilitySimulationJobEventPageDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_deliverability_test(self, test_id, **kwargs):  # noqa: E501
        """Get deliverability/load test  # noqa: E501

        Get deliverability test configuration and latest progress counters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_test(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_deliverability_test_with_http_info(test_id, **kwargs)  # noqa: E501

    def get_deliverability_test_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Get deliverability/load test  # noqa: E501

        Get deliverability test configuration and latest progress counters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_test_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `get_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_deliverability_test_results(self, test_id, **kwargs):  # noqa: E501
        """Get deliverability/load test entity results  # noqa: E501

        Get paged per-entity expectation results with optional matched/unmatched filtering.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_test_results(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param bool matched:
        :param int page:
        :param int size:
        :param str sort:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityEntityResultPageDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_deliverability_test_results_with_http_info(test_id, **kwargs)  # noqa: E501

    def get_deliverability_test_results_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Get deliverability/load test entity results  # noqa: E501

        Get paged per-entity expectation results with optional matched/unmatched filtering.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_test_results_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param bool matched:
        :param int page:
        :param int size:
        :param str sort:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityEntityResultPageDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'matched',
            'page',
            'size',
            'sort'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_deliverability_test_results" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `get_deliverability_test_results`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []
        if 'matched' in local_var_params and local_var_params['matched'] is not None:  # noqa: E501
            query_params.append(('matched', local_var_params['matched']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/results', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityEntityResultPageDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_deliverability_tests(self, **kwargs):  # noqa: E501
        """List deliverability/load tests  # noqa: E501

        List deliverability tests for the authenticated account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_tests(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Page index
        :param int size: Page size
        :param str sort: Sort direction
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestPageDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_deliverability_tests_with_http_info(**kwargs)  # noqa: E501

    def get_deliverability_tests_with_http_info(self, **kwargs):  # noqa: E501
        """List deliverability/load tests  # noqa: E501

        List deliverability tests for the authenticated account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_deliverability_tests_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Page index
        :param int size: Page size
        :param str sort: Sort direction
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestPageDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'page',
            'size',
            'sort'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_deliverability_tests" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestPageDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_latest_deliverability_simulation_job(self, test_id, **kwargs):  # noqa: E501
        """Get latest deliverability simulation job  # noqa: E501

        Get the most recent simulation job for a deliverability test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_deliverability_simulation_job(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilitySimulationJobDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_latest_deliverability_simulation_job_with_http_info(test_id, **kwargs)  # noqa: E501

    def get_latest_deliverability_simulation_job_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Get latest deliverability simulation job  # noqa: E501

        Get the most recent simulation job for a deliverability test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_deliverability_simulation_job_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilitySimulationJobDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_latest_deliverability_simulation_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `get_latest_deliverability_simulation_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/simulation-jobs/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilitySimulationJobDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pause_deliverability_simulation_job(self, test_id, job_id, **kwargs):  # noqa: E501
        """Pause deliverability simulation job  # noqa: E501

        Pause a running simulation job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_deliverability_simulation_job(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilitySimulationJobDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.pause_deliverability_simulation_job_with_http_info(test_id, job_id, **kwargs)  # noqa: E501

    def pause_deliverability_simulation_job_with_http_info(self, test_id, job_id, **kwargs):  # noqa: E501
        """Pause deliverability simulation job  # noqa: E501

        Pause a running simulation job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_deliverability_simulation_job_with_http_info(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilitySimulationJobDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'job_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pause_deliverability_simulation_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `pause_deliverability_simulation_job`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_id` when calling `pause_deliverability_simulation_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501
        if 'job_id' in local_var_params:
            path_params['jobId'] = local_var_params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/simulation-jobs/{jobId}/pause', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilitySimulationJobDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pause_deliverability_test(self, test_id, **kwargs):  # noqa: E501
        """Pause deliverability/load test  # noqa: E501

        Pause a RUNNING or SCHEDULED deliverability test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_deliverability_test(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.pause_deliverability_test_with_http_info(test_id, **kwargs)  # noqa: E501

    def pause_deliverability_test_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Pause deliverability/load test  # noqa: E501

        Pause a RUNNING or SCHEDULED deliverability test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_deliverability_test_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pause_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `pause_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/pause', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def poll_deliverability_test_status(self, test_id, **kwargs):  # noqa: E501
        """Poll deliverability/load test status  # noqa: E501

        Poll test progress. Evaluation is throttled with a 5-second cache window to protect backing data stores.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.poll_deliverability_test_status(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityPollStatusResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.poll_deliverability_test_status_with_http_info(test_id, **kwargs)  # noqa: E501

    def poll_deliverability_test_status_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Poll deliverability/load test status  # noqa: E501

        Poll test progress. Evaluation is throttled with a 5-second cache window to protect backing data stores.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.poll_deliverability_test_status_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityPollStatusResultDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method poll_deliverability_test_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `poll_deliverability_test_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityPollStatusResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_deliverability_simulation_job(self, test_id, job_id, **kwargs):  # noqa: E501
        """Resume deliverability simulation job  # noqa: E501

        Resume a paused simulation job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_deliverability_simulation_job(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilitySimulationJobDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.resume_deliverability_simulation_job_with_http_info(test_id, job_id, **kwargs)  # noqa: E501

    def resume_deliverability_simulation_job_with_http_info(self, test_id, job_id, **kwargs):  # noqa: E501
        """Resume deliverability simulation job  # noqa: E501

        Resume a paused simulation job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_deliverability_simulation_job_with_http_info(test_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param str job_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilitySimulationJobDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'job_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_deliverability_simulation_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `resume_deliverability_simulation_job`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_id` when calling `resume_deliverability_simulation_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501
        if 'job_id' in local_var_params:
            path_params['jobId'] = local_var_params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/simulation-jobs/{jobId}/resume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilitySimulationJobDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_deliverability_test(self, test_id, **kwargs):  # noqa: E501
        """Start or resume deliverability/load test  # noqa: E501

        Start a CREATED test or resume a PAUSED/SCHEDULED test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_deliverability_test(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_deliverability_test_with_http_info(test_id, **kwargs)  # noqa: E501

    def start_deliverability_test_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Start or resume deliverability/load test  # noqa: E501

        Start a CREATED test or resume a PAUSED/SCHEDULED test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_deliverability_test_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `start_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/start', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stop_deliverability_test(self, test_id, **kwargs):  # noqa: E501
        """Stop deliverability/load test  # noqa: E501

        Stop a deliverability test and mark it terminal.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_deliverability_test(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.stop_deliverability_test_with_http_info(test_id, **kwargs)  # noqa: E501

    def stop_deliverability_test_with_http_info(self, test_id, **kwargs):  # noqa: E501
        """Stop deliverability/load test  # noqa: E501

        Stop a deliverability test and mark it terminal.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_deliverability_test_with_http_info(test_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stop_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `stop_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}/stop', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_deliverability_test(self, test_id, update_deliverability_test_options, **kwargs):  # noqa: E501
        """Update deliverability/load test  # noqa: E501

        Update metadata, timeout, and expectations for a non-running non-terminal test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_deliverability_test(test_id, update_deliverability_test_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param UpdateDeliverabilityTestOptions update_deliverability_test_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeliverabilityTestDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_deliverability_test_with_http_info(test_id, update_deliverability_test_options, **kwargs)  # noqa: E501

    def update_deliverability_test_with_http_info(self, test_id, update_deliverability_test_options, **kwargs):  # noqa: E501
        """Update deliverability/load test  # noqa: E501

        Update metadata, timeout, and expectations for a non-running non-terminal test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_deliverability_test_with_http_info(test_id, update_deliverability_test_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str test_id: (required)
        :param UpdateDeliverabilityTestOptions update_deliverability_test_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeliverabilityTestDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'test_id',
            'update_deliverability_test_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_deliverability_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'test_id' is set
        if self.api_client.client_side_validation and ('test_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['test_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `test_id` when calling `update_deliverability_test`")  # noqa: E501
        # verify the required parameter 'update_deliverability_test_options' is set
        if self.api_client.client_side_validation and ('update_deliverability_test_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_deliverability_test_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_deliverability_test_options` when calling `update_deliverability_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'test_id' in local_var_params:
            path_params['testId'] = local_var_params['test_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_deliverability_test_options' in local_var_params:
            body_params = local_var_params['update_deliverability_test_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/test/deliverability/{testId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeliverabilityTestDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityTestDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'scope': 'str',
        'selector': 'DeliverabilitySelectorOptions',
        'selected_entity_count': 'int',
        'expectations': 'list[DeliverabilityExpectation]',
        'status': 'str',
        'start_at': 'datetime',
        'started_at': 'datetime',
        'completed_at': 'datetime',
        'max_duration_seconds': 'int',
        'success_threshold_percent': 'float',
        'threshold_status': 'str',
        'threshold_met': 'bool',
        'last_evaluated_at': 'datetime',
        'total_entities': 'int',
        'matched_entities': 'int',
        'unmatched_entities': 'int',
        'completion_percentage': 'float',
        'timed_out': 'bool',
        'failure_reason': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'scope': 'scope',
        'selector': 'selector',
        'selected_entity_count': 'selectedEntityCount',
        'expectations': 'expectations',
        'status': 'status',
        'start_at': 'startAt',
        'started_at': 'startedAt',
        'completed_at': 'completedAt',
        'max_duration_seconds': 'maxDurationSeconds',
        'success_threshold_percent': 'successThresholdPercent',
        'threshold_status': 'thresholdStatus',
        'threshold_met': 'thresholdMet',
        'last_evaluated_at': 'lastEvaluatedAt',
        'total_entities': 'totalEntities',
        'matched_entities': 'matchedEntities',
        'unmatched_entities': 'unmatchedEntities',
        'completion_percentage': 'completionPercentage',
        'timed_out': 'timedOut',
        'failure_reason': 'failureReason',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, name=None, description=None, scope=None, selector=None, selected_entity_count=None, expectations=None, status=None, start_at=None, started_at=None, completed_at=None, max_duration_seconds=None, success_threshold_percent=None, threshold_status=None, threshold_met=None, last_evaluated_at=None, total_entities=None, matched_entities=None, unmatched_entities=None, completion_percentage=None, timed_out=None, failure_reason=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityTestDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._scope = None
        self._selector = None
        self._selected_entity_count = None
        self._expectations = None
        self._status = None
        self._start_at = None
        self._started_at = None
        self._completed_at = None
        self._max_duration_seconds = None
        self._success_threshold_percent = None
        self._threshold_status = None
        self._threshold_met = None
        self._last_evaluated_at = None
        self._total_entities = None
        self._matched_entities = None
        self._unmatched_entities = None
        self._completion_percentage = None
        self._timed_out = None
        self._failure_reason = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.description = description
        self.scope = scope
        self.selector = selector
        self.selected_entity_count = selected_entity_count
        self.expectations = expectations
        self.status = status
        self.start_at = start_at
        self.started_at = started_at
        self.completed_at = completed_at
        self.max_duration_seconds = max_duration_seconds
        self.success_threshold_percent = success_threshold_percent
        self.threshold_status = threshold_status
        self.threshold_met = threshold_met
        self.last_evaluated_at = last_evaluated_at
        self.total_entities = total_entities
        self.matched_entities = matched_entities
        self.unmatched_entities = unmatched_entities
        self.completion_percentage = completion_percentage
        self.timed_out = timed_out
        self.failure_reason = failure_reason
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DeliverabilityTestDto.  # noqa: E501


        :return: The id of this DeliverabilityTestDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeliverabilityTestDto.


        :param id: The id of this DeliverabilityTestDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this DeliverabilityTestDto.  # noqa: E501


        :return: The name of this DeliverabilityTestDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeliverabilityTestDto.


        :param name: The name of this DeliverabilityTestDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this DeliverabilityTestDto.  # noqa: E501


        :return: The description of this DeliverabilityTestDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DeliverabilityTestDto.


        :param description: The description of this DeliverabilityTestDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def scope(self):
        """Gets the scope of this DeliverabilityTestDto.  # noqa: E501


        :return: The scope of this DeliverabilityTestDto.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this DeliverabilityTestDto.


        :param scope: The scope of this DeliverabilityTestDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and scope is None:  # noqa: E501
            raise ValueError("Invalid value for `scope`, must not be `None`")  # noqa: E501
        allowed_values = ["INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and scope not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def selector(self):
        """Gets the selector of this DeliverabilityTestDto.  # noqa: E501


        :return: The selector of this DeliverabilityTestDto.  # noqa: E501
        :rtype: DeliverabilitySelectorOptions
        """
        return self._selector

    @selector.setter
    def selector(self, selector):
        """Sets the selector of this DeliverabilityTestDto.


        :param selector: The selector of this DeliverabilityTestDto.  # noqa: E501
        :type: DeliverabilitySelectorOptions
        """
        if self.local_vars_configuration.client_side_validation and selector is None:  # noqa: E501
            raise ValueError("Invalid value for `selector`, must not be `None`")  # noqa: E501

        self._selector = selector

    @property
    def selected_entity_count(self):
        """Gets the selected_entity_count of this DeliverabilityTestDto.  # noqa: E501


        :return: The selected_entity_count of this DeliverabilityTestDto.  # noqa: E501
        :rtype: int
        """
        return self._selected_entity_count

    @selected_entity_count.setter
    def selected_entity_count(self, selected_entity_count):
        """Sets the selected_entity_count of this DeliverabilityTestDto.


        :param selected_entity_count: The selected_entity_count of this DeliverabilityTestDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and selected_entity_count is None:  # noqa: E501
            raise ValueError("Invalid value for `selected_entity_count`, must not be `None`")  # noqa: E501

        self._selected_entity_count = selected_entity_count

    @property
    def expectations(self):
        """Gets the expectations of this DeliverabilityTestDto.  # noqa: E501


        :return: The expectations of this DeliverabilityTestDto.  # noqa: E501
        :rtype: list[DeliverabilityExpectation]
        """
        return self._expectations

    @expectations.setter
    def expectations(self, expectations):
        """Sets the expectations of this DeliverabilityTestDto.


        :param expectations: The expectations of this DeliverabilityTestDto.  # noqa: E501
        :type: list[DeliverabilityExpectation]
        """
        if self.local_vars_configuration.client_side_validation and expectations is None:  # noqa: E501
            raise ValueError("Invalid value for `expectations`, must not be `None`")  # noqa: E501

        self._expectations = expectations

    @property
    def status(self):
        """Gets the status of this DeliverabilityTestDto.  # noqa: E501


        :return: The status of this DeliverabilityTestDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeliverabilityTestDto.


        :param status: The status of this DeliverabilityTestDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["CREATED", "SCHEDULED", "RUNNING", "PAUSED", "STOPPED", "COMPLETE", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def start_at(self):
        """Gets the start_at of this DeliverabilityTestDto.  # noqa: E501


        :return: The start_at of this DeliverabilityTestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._start_at

    @start_at.setter
    def start_at(self, start_at):
        """Sets the start_at of this DeliverabilityTestDto.


        :param start_at: The start_at of this DeliverabilityTestDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and start_at is None:  # noqa: E501
            raise ValueError("Invalid value for `start_at`, must not be `None`")  # noqa: E501

        self._start_at = start_at

    @property
    def started_at(self):
        """Gets the started_at of this DeliverabilityTestDto.  # noqa: E501


        :return: The started_at of this DeliverabilityTestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this DeliverabilityTestDto.


        :param started_at: The started_at of this DeliverabilityTestDto.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def completed_at(self):
        """Gets the completed_at of this DeliverabilityTestDto.  # noqa: E501


        :return: The completed_at of this DeliverabilityTestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this DeliverabilityTestDto.


        :param completed_at: The completed_at of this DeliverabilityTestDto.  # noqa: E501
        :type: datetime
        """

        self._completed_at = completed_at

    @property
    def max_duration_seconds(self):
        """Gets the max_duration_seconds of this DeliverabilityTestDto.  # noqa: E501


        :return: The max_duration_seconds of this DeliverabilityTestDto.  # noqa: E501
        :rtype: int
        """
        return self._max_duration_seconds

    @max_duration_seconds.setter
    def max_duration_seconds(self, max_duration_seconds):
        """Sets the max_duration_seconds of this DeliverabilityTestDto.


        :param max_duration_seconds: The max_duration_seconds of this DeliverabilityTestDto.  # noqa: E501
        :type: int
        """

        self._max_duration_seconds = max_duration_seconds

    @property
    def success_threshold_percent(self):
        """Gets the success_threshold_percent of this DeliverabilityTestDto.  # noqa: E501


        :return: The success_threshold_percent of this DeliverabilityTestDto.  # noqa: E501
        :rtype: float
        """
        return self._success_threshold_percent

    @success_threshold_percent.setter
    def success_threshold_percent(self, success_threshold_percent):
        """Sets the success_threshold_percent of this DeliverabilityTestDto.


        :param success_threshold_percent: The success_threshold_percent of this DeliverabilityTestDto.  # noqa: E501
        :type: float
        """

        self._success_threshold_percent = success_threshold_percent

    @property
    def threshold_status(self):
        """Gets the threshold_status of this DeliverabilityTestDto.  # noqa: E501


        :return: The threshold_status of this DeliverabilityTestDto.  # noqa: E501
        :rtype: str
        """
        return self._threshold_status

    @threshold_status.setter
    def threshold_status(self, threshold_status):
        """Sets the threshold_status of this DeliverabilityTestDto.


        :param threshold_status: The threshold_status of this DeliverabilityTestDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and threshold_status is None:  # noqa: E501
            raise ValueError("Invalid value for `threshold_status`, must not be `None`")  # noqa: E501
        allowed_values = ["NOT_CONFIGURED", "PASSING", "FAILING"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and threshold_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `threshold_status` ({0}), must be one of {1}"  # noqa: E501
                .format(threshold_status, allowed_values)
            )

        self._threshold_status = threshold_status

    @property
    def threshold_met(self):
        """Gets the threshold_met of this DeliverabilityTestDto.  # noqa: E501


        :return: The threshold_met of this DeliverabilityTestDto.  # noqa: E501
        :rtype: bool
        """
        return self._threshold_met

    @threshold_met.setter
    def threshold_met(self, threshold_met):
        """Sets the threshold_met of this DeliverabilityTestDto.


        :param threshold_met: The threshold_met of this DeliverabilityTestDto.  # noqa: E501
        :type: bool
        """

        self._threshold_met = threshold_met

    @property
    def last_evaluated_at(self):
        """Gets the last_evaluated_at of this DeliverabilityTestDto.  # noqa: E501


        :return: The last_evaluated_at of this DeliverabilityTestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_evaluated_at

    @last_evaluated_at.setter
    def last_evaluated_at(self, last_evaluated_at):
        """Sets the last_evaluated_at of this DeliverabilityTestDto.


        :param last_evaluated_at: The last_evaluated_at of this DeliverabilityTestDto.  # noqa: E501
        :type: datetime
        """

        self._last_evaluated_at = last_evaluated_at

    @property
    def total_entities(self):
        """Gets the total_entities of this DeliverabilityTestDto.  # noqa: E501


        :return: The total_entities of this DeliverabilityTestDto.  # noqa: E501
        :rtype: int
        """
        return self._total_entities

    @total_entities.setter
    def total_entities(self, total_entities):
        """Sets the total_entities of this DeliverabilityTestDto.


        :param total_entities: The total_entities of this DeliverabilityTestDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_entities is None:  # noqa: E501
            raise ValueError("Invalid value for `total_entities`, must not be `None`")  # noqa: E501

        self._total_entities = total_entities

    @property
    def matched_entities(self):
        """Gets the matched_entities of this DeliverabilityTestDto.  # noqa: E501


        :return: The matched_entities of this DeliverabilityTestDto.  # noqa: E501
        :rtype: int
        """
        return self._matched_entities

    @matched_entities.setter
    def matched_entities(self, matched_entities):
        """Sets the matched_entities of this DeliverabilityTestDto.


        :param matched_entities: The matched_entities of this DeliverabilityTestDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and matched_entities is None:  # noqa: E501
            raise ValueError("Invalid value for `matched_entities`, must not be `None`")  # noqa: E501

        self._matched_entities = matched_entities

    @property
    def unmatched_entities(self):
        """Gets the unmatched_entities of this DeliverabilityTestDto.  # noqa: E501


        :return: The unmatched_entities of this DeliverabilityTestDto.  # noqa: E501
        :rtype: int
        """
        return self._unmatched_entities

    @unmatched_entities.setter
    def unmatched_entities(self, unmatched_entities):
        """Sets the unmatched_entities of this DeliverabilityTestDto.


        :param unmatched_entities: The unmatched_entities of this DeliverabilityTestDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and unmatched_entities is None:  # noqa: E501
            raise ValueError("Invalid value for `unmatched_entities`, must not be `None`")  # noqa: E501

        self._unmatched_entities = unmatched_entities

    @property
    def completion_percentage(self):
        """Gets the completion_percentage of this DeliverabilityTestDto.  # noqa: E501


        :return: The completion_percentage of this DeliverabilityTestDto.  # noqa: E501
        :rtype: float
        """
        return self._completion_percentage

    @completion_percentage.setter
    def completion_percentage(self, completion_percentage):
        """Sets the completion_percentage of this DeliverabilityTestDto.


        :param completion_percentage: The completion_percentage of this DeliverabilityTestDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and completion_percentage is None:  # noqa: E501
            raise ValueError("Invalid value for `completion_percentage`, must not be `None`")  # noqa: E501

        self._completion_percentage = completion_percentage

    @property
    def timed_out(self):
        """Gets the timed_out of this DeliverabilityTestDto.  # noqa: E501


        :return: The timed_out of this DeliverabilityTestDto.  # noqa: E501
        :rtype: bool
        """
        return self._timed_out

    @timed_out.setter
    def timed_out(self, timed_out):
        """Sets the timed_out of this DeliverabilityTestDto.


        :param timed_out: The timed_out of this DeliverabilityTestDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and timed_out is None:  # noqa: E501
            raise ValueError("Invalid value for `timed_out`, must not be `None`")  # noqa: E501

        self._timed_out = timed_out

    @property
    def failure_reason(self):
        """Gets the failure_reason of this DeliverabilityTestDto.  # noqa: E501


        :return: The failure_reason of this DeliverabilityTestDto.  # noqa: E501
        :rtype: str
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this DeliverabilityTestDto.


        :param failure_reason: The failure_reason of this DeliverabilityTestDto.  # noqa: E501
        :type: str
        """

        self._failure_reason = failure_reason

    @property
    def created_at(self):
        """Gets the created_at of this DeliverabilityTestDto.  # noqa: E501


        :return: The created_at of this DeliverabilityTestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DeliverabilityTestDto.


        :param created_at: The created_at of this DeliverabilityTestDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DeliverabilityTestDto.  # noqa: E501


        :return: The updated_at of this DeliverabilityTestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DeliverabilityTestDto.


        :param updated_at: The updated_at of this DeliverabilityTestDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityTestDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityTestDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'created_at': 'datetime',
        'conditions': 'list[str]',
        'instructions': 'list[str]',
        'output_schema': 'StructuredOutputSchema'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'created_at': 'createdAt',
        'conditions': 'conditions',
        'instructions': 'instructions',
        'output_schema': 'outputSchema'
    }

    def __init__(self, name=None, id=None, created_at=None, conditions=None, instructions=None, output_schema=None, local_vars_configuration=None):  # noqa: E501
        """AITransformProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._created_at = None
        self._conditions = None
        self._instructions = None
        self._output_schema = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.id = id
        self.created_at = created_at
        if conditions is not None:
            self.conditions = conditions
        if instructions is not None:
            self.instructions = instructions
        self.output_schema = output_schema

    @property
    def name(self):
        """Gets the name of this AITransformProjection.  # noqa: E501


        :return: The name of this AITransformProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AITransformProjection.


        :param name: The name of this AITransformProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this AITransformProjection.  # noqa: E501


        :return: The id of this AITransformProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AITransformProjection.


        :param id: The id of this AITransformProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this AITransformProjection.  # noqa: E501


        :return: The created_at of this AITransformProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AITransformProjection.


        :param created_at: The created_at of this AITransformProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def conditions(self):
        """Gets the conditions of this AITransformProjection.  # noqa: E501


        :return: The conditions of this AITransformProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this AITransformProjection.


        :param conditions: The conditions of this AITransformProjection.  # noqa: E501
        :type: list[str]
        """

        self._conditions = conditions

    @property
    def instructions(self):
        """Gets the instructions of this AITransformProjection.  # noqa: E501


        :return: The instructions of this AITransformProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this AITransformProjection.


        :param instructions: The instructions of this AITransformProjection.  # noqa: E501
        :type: list[str]
        """

        self._instructions = instructions

    @property
    def output_schema(self):
        """Gets the output_schema of this AITransformProjection.  # noqa: E501


        :return: The output_schema of this AITransformProjection.  # noqa: E501
        :rtype: StructuredOutputSchema
        """
        return self._output_schema

    @output_schema.setter
    def output_schema(self, output_schema):
        """Sets the output_schema of this AITransformProjection.


        :param output_schema: The output_schema of this AITransformProjection.  # noqa: E501
        :type: StructuredOutputSchema
        """

        self._output_schema = output_schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class LookupPtrResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ip': 'str',
        'ptr_hostnames': 'list[str]',
        'forward_confirmed': 'bool',
        'forward_a_records': 'list[str]',
        'forward_aaaa_records': 'list[str]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'ip': 'ip',
        'ptr_hostnames': 'ptrHostnames',
        'forward_confirmed': 'forwardConfirmed',
        'forward_a_records': 'forwardARecords',
        'forward_aaaa_records': 'forwardAaaaRecords',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, ip=None, ptr_hostnames=None, forward_confirmed=None, forward_a_records=None, forward_aaaa_records=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """LookupPtrResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ip = None
        self._ptr_hostnames = None
        self._forward_confirmed = None
        self._forward_a_records = None
        self._forward_aaaa_records = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.ip = ip
        self.ptr_hostnames = ptr_hostnames
        self.forward_confirmed = forward_confirmed
        self.forward_a_records = forward_a_records
        self.forward_aaaa_records = forward_aaaa_records
        self.warnings = warnings
        self.errors = errors

    @property
    def ip(self):
        """Gets the ip of this LookupPtrResults.  # noqa: E501


        :return: The ip of this LookupPtrResults.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this LookupPtrResults.


        :param ip: The ip of this LookupPtrResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ip is None:  # noqa: E501
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def ptr_hostnames(self):
        """Gets the ptr_hostnames of this LookupPtrResults.  # noqa: E501


        :return: The ptr_hostnames of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._ptr_hostnames

    @ptr_hostnames.setter
    def ptr_hostnames(self, ptr_hostnames):
        """Sets the ptr_hostnames of this LookupPtrResults.


        :param ptr_hostnames: The ptr_hostnames of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and ptr_hostnames is None:  # noqa: E501
            raise ValueError("Invalid value for `ptr_hostnames`, must not be `None`")  # noqa: E501

        self._ptr_hostnames = ptr_hostnames

    @property
    def forward_confirmed(self):
        """Gets the forward_confirmed of this LookupPtrResults.  # noqa: E501


        :return: The forward_confirmed of this LookupPtrResults.  # noqa: E501
        :rtype: bool
        """
        return self._forward_confirmed

    @forward_confirmed.setter
    def forward_confirmed(self, forward_confirmed):
        """Sets the forward_confirmed of this LookupPtrResults.


        :param forward_confirmed: The forward_confirmed of this LookupPtrResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and forward_confirmed is None:  # noqa: E501
            raise ValueError("Invalid value for `forward_confirmed`, must not be `None`")  # noqa: E501

        self._forward_confirmed = forward_confirmed

    @property
    def forward_a_records(self):
        """Gets the forward_a_records of this LookupPtrResults.  # noqa: E501


        :return: The forward_a_records of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._forward_a_records

    @forward_a_records.setter
    def forward_a_records(self, forward_a_records):
        """Sets the forward_a_records of this LookupPtrResults.


        :param forward_a_records: The forward_a_records of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and forward_a_records is None:  # noqa: E501
            raise ValueError("Invalid value for `forward_a_records`, must not be `None`")  # noqa: E501

        self._forward_a_records = forward_a_records

    @property
    def forward_aaaa_records(self):
        """Gets the forward_aaaa_records of this LookupPtrResults.  # noqa: E501


        :return: The forward_aaaa_records of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._forward_aaaa_records

    @forward_aaaa_records.setter
    def forward_aaaa_records(self, forward_aaaa_records):
        """Sets the forward_aaaa_records of this LookupPtrResults.


        :param forward_aaaa_records: The forward_aaaa_records of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and forward_aaaa_records is None:  # noqa: E501
            raise ValueError("Invalid value for `forward_aaaa_records`, must not be `None`")  # noqa: E501

        self._forward_aaaa_records = forward_aaaa_records

    @property
    def warnings(self):
        """Gets the warnings of this LookupPtrResults.  # noqa: E501


        :return: The warnings of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this LookupPtrResults.


        :param warnings: The warnings of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this LookupPtrResults.  # noqa: E501


        :return: The errors of this LookupPtrResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this LookupPtrResults.


        :param errors: The errors of this LookupPtrResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LookupPtrResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LookupPtrResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AvailablePhoneNumberDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_number': 'str',
        'phone_country': 'str',
        'phone_variant': 'str',
        'line_type': 'str',
        'carrier_name': 'str',
        'mobile_country_code': 'str',
        'mobile_network_code': 'str',
        'provider_label': 'str'
    }

    attribute_map = {
        'phone_number': 'phoneNumber',
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'line_type': 'lineType',
        'carrier_name': 'carrierName',
        'mobile_country_code': 'mobileCountryCode',
        'mobile_network_code': 'mobileNetworkCode',
        'provider_label': 'providerLabel'
    }

    def __init__(self, phone_number=None, phone_country=None, phone_variant=None, line_type=None, carrier_name=None, mobile_country_code=None, mobile_network_code=None, provider_label=None, local_vars_configuration=None):  # noqa: E501
        """AvailablePhoneNumberDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_number = None
        self._phone_country = None
        self._phone_variant = None
        self._line_type = None
        self._carrier_name = None
        self._mobile_country_code = None
        self._mobile_network_code = None
        self._provider_label = None
        self.discriminator = None

        self.phone_number = phone_number
        self.phone_country = phone_country
        if phone_variant is not None:
            self.phone_variant = phone_variant
        if line_type is not None:
            self.line_type = line_type
        if carrier_name is not None:
            self.carrier_name = carrier_name
        if mobile_country_code is not None:
            self.mobile_country_code = mobile_country_code
        if mobile_network_code is not None:
            self.mobile_network_code = mobile_network_code
        if provider_label is not None:
            self.provider_label = provider_label

    @property
    def phone_number(self):
        """Gets the phone_number of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The phone_number of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this AvailablePhoneNumberDto.


        :param phone_number: The phone_number of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def phone_country(self):
        """Gets the phone_country of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The phone_country of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this AvailablePhoneNumberDto.


        :param phone_country: The phone_country of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The phone_variant of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this AvailablePhoneNumberDto.


        :param phone_variant: The phone_variant of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def line_type(self):
        """Gets the line_type of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The line_type of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._line_type

    @line_type.setter
    def line_type(self, line_type):
        """Sets the line_type of this AvailablePhoneNumberDto.


        :param line_type: The line_type of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._line_type = line_type

    @property
    def carrier_name(self):
        """Gets the carrier_name of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The carrier_name of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._carrier_name

    @carrier_name.setter
    def carrier_name(self, carrier_name):
        """Sets the carrier_name of this AvailablePhoneNumberDto.


        :param carrier_name: The carrier_name of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._carrier_name = carrier_name

    @property
    def mobile_country_code(self):
        """Gets the mobile_country_code of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The mobile_country_code of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._mobile_country_code

    @mobile_country_code.setter
    def mobile_country_code(self, mobile_country_code):
        """Sets the mobile_country_code of this AvailablePhoneNumberDto.


        :param mobile_country_code: The mobile_country_code of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._mobile_country_code = mobile_country_code

    @property
    def mobile_network_code(self):
        """Gets the mobile_network_code of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The mobile_network_code of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._mobile_network_code

    @mobile_network_code.setter
    def mobile_network_code(self, mobile_network_code):
        """Sets the mobile_network_code of this AvailablePhoneNumberDto.


        :param mobile_network_code: The mobile_network_code of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._mobile_network_code = mobile_network_code

    @property
    def provider_label(self):
        """Gets the provider_label of this AvailablePhoneNumberDto.  # noqa: E501


        :return: The provider_label of this AvailablePhoneNumberDto.  # noqa: E501
        :rtype: str
        """
        return self._provider_label

    @provider_label.setter
    def provider_label(self, provider_label):
        """Sets the provider_label of this AvailablePhoneNumberDto.


        :param provider_label: The provider_label of this AvailablePhoneNumberDto.  # noqa: E501
        :type: str
        """

        self._provider_label = provider_label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvailablePhoneNumberDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AvailablePhoneNumberDto):
            return True

        return self.to_dict() != other.to_dict()
